# django-microblog

![](https://img.shields.io/badge/Version-0.1.0-orange.svg?style=flat-square)
![](https://img.shields.io/badge/Django-2.0+-green.svg?style=flat-square)
![](https://img.shields.io/badge/License-MIT-blue.svg?style=flat-square)

django-microblog minimal blogging application for Django

## Getting started

1. Installation

```bash
pip install django-microblog
```

2. Add **microblog** into **INSTALLED_APPS** in your settings file.